@@ -1,12 +1,11 @@
 /* astroCommon.m
  * Common astronomical functions
  *
- * Copyright (C) 1998-2009 by vhf interservice GmbH
+ * Copyright (C) 1998-2005 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1998-11-06
- * modified: 2009-04-08 (modulo())
- *           2006-04-06 (Pholus ']' added, Pallas '[' corrected, new astro functions without NSCalendarDate)
+ * modified: 2005-03-15 (midpoint())
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -320,17 +319,17 @@ double *harmonicPattern1(int tableSize)
 /* "430'00" -> 4.5 or 4.5
  */
 float degFromString(NSString *degString)
-{   float           deg = 0.0;
-    NSScanner       *scanner = [NSScanner scannerWithString:degString];
-    NSCharacterSet  *digitSet  = [NSCharacterSet decimalDigitCharacterSet];
-    NSCharacterSet  *degreeSet = [NSCharacterSet characterSetWithCharactersInString:@" .'\""];
-    NSString        *string;
-    NSRange         range;
+{   float		deg = 0.0;
+    NSScanner		*scanner = [NSScanner scannerWithString:degString];
+    NSCharacterSet	*digitSet = [NSCharacterSet decimalDigitCharacterSet];
+    NSCharacterSet	*degreeSet = [NSCharacterSet characterSetWithCharactersInString:@" '\""];
+    NSString		*string;
+    NSRange		range;
 
     range = [degString rangeOfCharacterFromSet:degreeSet];
-    if ( !range.length )	// 4.5
+    if ( !range.length )
         deg = [degString floatValue];
-    else			// 4 30'00"
+    else
     {
         if ( [scanner scanCharactersFromSet:digitSet intoString:&string] )
             deg += [string floatValue];
@@ -344,7 +343,7 @@ float degFromString(NSString *degString)
     return deg;
 }
 
-/* created: 1997-08-21
+/* created: 21.08.97
  */
 int sortAsNumbers(id str1, id str2, void *context)
 {
@@ -355,9 +354,9 @@ int sortAsNumbers(id str1, id str2, void *context)
     return NSOrderedSame;
 }
 
-/* MJD: modified julian day (starting in 1858)
+/* MJD: modified julian date
  */
-double vhfMJD( NSCalendarDate *date )
+double mjd( NSCalendarDate *date )
 {   int		year, month, day;
     double	hour, mjd;
     double	a, b;
@@ -369,7 +368,8 @@ double vhfMJD( NSCalendarDate *date )
 
     a = 10000.0*year + 100.0*month + day;
     if ( month <= 2 )
-    {   month += 12;
+    {
+        month += 12;
         year--;
     }
     if ( a <= 15821004.1 )
@@ -407,110 +407,10 @@ NSCalendarDate *dateFromMJD(double mjd)
     sec = ((24.0*(jd+0.5-jd0) - hour) - min*60.0)/3600.0;
 
     date = [NSCalendarDate dateWithYear:year month:month day:day hour:hour minute:min second:sec
-                               timeZone:[NSTimeZone timeZoneForSecondsFromGMT:0]];
+                               timeZone:[NSTimeZone timeZoneWithName:@"UTC"]];
     return date;
 }
 
-double vhfSideralTimeMJD(double mjd, float lon)
-{   double	mj = mjd, mjd0, t, ut, gmst, lmst;
-
-    mjd0 = floor( mj );
-    ut = (mj-mjd0)*24;
-    t = (mjd0-51544.5)/36525.0;
-    gmst = 6.697374558+1.0027379093*ut+(8640184.812866+(0.093104-6.2e-6*t)*t)*t/3600.0;
-    lmst = 24.0*frac((gmst+lon/15.0)/24.0);
-    return lmst;	// hours
-}
-
-
-/* Julian day from Calendar Date (starting -4712)
- */
-double vhfJulianDay(NSCalendarDate *date)
-{   int		year, month, day;
-    double	hour, y0, y1, jd;
-
-    year  = [date yearOfCommonEra];
-    month = [date monthOfYear];
-    day   = [date dayOfMonth];
-    hour  = (double)[date hourOfDay]+[date minuteOfHour]/60.0+[date secondOfMinute]/3600.0;
-
-    if ( month <= 2 )
-    {   month += 12;
-        year--;
-    }
-    y0 = year;
-    jd = floor((y0+4712.0)*365.25) + floor(30.6*(month+1.0)+0.000001) + day + hour/24.0 - 63.5;
-
-    y1 = Abs(year)/100 - Abs(year)/400;
-    if (year < 0)
-        y1 = -y1;
-    jd = jd - y1 + 2.0;
-    if ((year < 0) && (y0/100.0 == floor(y0/100.0)) && (y0/400.0 != floor(y0/400.0)))
-        jd -= 1.0;
-
-    return jd;
-}
-
-/* Julian day (starting -4712)
- * modified: 2008-10-16 (hour had integer conversion error = too big)
- */
-double vhfJulianDayFromInt(int yyyymmdd, int hhmm)
-{   int		year, month, day;
-    double	hour, y0, y1, jd;
-
-    year  = yyyymmdd / 10000;
-    yyyymmdd -= yyyymmdd/10000*10000;
-    month = yyyymmdd / 100;
-    yyyymmdd -= yyyymmdd/100*100;
-    day   = yyyymmdd;
-    hour  = (double)(hhmm/100) + (double)(hhmm-(hhmm/100*100)) / 60.0;
-
-    if ( month <= 2 )
-    {   month += 12;
-        year--;
-    }
-    y0 = year;
-    jd = floor((y0+4712.0)*365.25) + floor(30.6*(month+1.0)+0.000001) + day + hour/24.0 - 63.5;
-
-    y1 = Abs(year)/100 - Abs(year)/400;
-    if (year < 0)
-        y1 = -y1;
-    jd = jd - y1 + 2.0;
-    if ((year < 0) && (y0/100.0 == floor(y0/100.0)) && (y0/400.0 != floor(y0/400.0)))
-        jd -= 1.0;
-
-    return jd;
-}
-/* date from Julian day (starting -4712)
- */
-int vhfIntDateFromJulianDay(double jd, int *yyyymmdd, int *hhmm)
-{   int		year, month, day, yymmdd;
-    double	u0, u1, u2, u3, u4, hour;
-
-    u0 = jd + 32082.5;
-    u1 = u0 + floor(u0/36525.0) - floor(u0/146100.0) - 38.0;
-    if (jd >= 1830691.5)
-        u1 += 1;
-    u0 = u0 + floor(u1/36525.0) - floor(u1/146100.0) - 38.0;
-
-    u2 = floor(u0 + 123.0);
-    u3 = floor((u2 - 122.2) / 365.25);
-    u4 = floor((u2 - floor(365.25 * u3) ) / 30.6001);
-    month = (int)(u4 - 1.0);
-    if (month > 12)
-        month -= 12;
-    day   = (int) (u2 - floor(365.25 * u3) - floor(30.6001 * u4));
-    year  = (int) (u3 + floor((u4 - 2.0) / 12.0) - 4800);
-    hour  = (jd - floor(jd + 0.5) + 0.5) * 24.0;
-
-    yymmdd = year*10000 + month*100 + day;
-    if (yyyymmdd)
-        *yyyymmdd = yymmdd;
-    if (hhmm)
-        *hhmm     = (int)hour*100 + (int)((hour-floor(hour))*60.0);
-    return yymmdd;
-}
-
 /* gmt to local time
  * start at 22.09. 00:00 UTC
  * each 24h (86400s) +4 minutes (star day = 23:56:04.1) -> +235.9 sec
@@ -522,183 +422,28 @@ float frac(float x)
     if (x<0) x += 1.0;
     return x;
 }
-
-
-/* sideral time in hours with comma (reference date = -4712)
- */
-double vhfSideralTime(double jd, float lon)
-{   double	mj = jd, mjd0, t, ut, gmst, lmst;
-
-    mjd0 = floor(mj);
-    ut = (mj-mjd0-0.5) * 24.0;
-    t = (mjd0-2451544.5) / 36525.0;
-    gmst = 6.697374558+1.0027379093*ut+(8640184.812866+(0.093104-6.2e-6*t)*t)*t/3600.0;
-    lmst = 24.0*frac((gmst+lon/15.0)/24.0);
-    return lmst;	// hours
-}
-
-float vhfLonForSideralTime(double st, NSCalendarDate *gmt)
-{   double	mj, mjd0, t, ut, gmst, lon;
-
-    mj = vhfMJD(gmt);
-    mjd0 = floor(mj);
-    ut = (mj-mjd0)*24;
-    t = (mjd0-51544.5)/36525.0;
-    gmst = 6.697374558+1.0027379093*ut+(8640184.812866+(0.093104-6.2e-6*t)*t)*t/3600.0;
-    lon = (st - gmst) * 15.0;
-
-    while (lon <= -180.0)
-        lon += 360.0;
-    while (lon > 180.0)
-        lon -= 360.0;
-
-    return lon;
-}
-
-double vhfRA(double st)
-{
-    return st * 15.0;
-}
-
-double vhfMC(double st)
-{   double	l, mc, ra;
-
-    ra = st * 15.0;	// secs / (4.0*60.0);
-    l = COS_E * Cot(ra);
-    mc = Acot(l);
-    if ( mc < 0.0 )
-        mc += 360.0;
-
-    /* from 12:00 - 00:00 sideralTime -> mc = 180 - 360 degree
-     * from 00:00 - 12:00 sideralTime -> mc = 0 - 180 degree
-     * -06:00 -> mc
-     * 06:00- -> mc -= 180.0
-     */
-    if ( st >= 0.0 && st < 12.0 )
-    {
-        if ( mc > 180.0 )
-            mc -= 180.0;
-    }
-    else if ( mc < 180.0 )
-        mc += 180.0;
-
-    if ( mc < 0.0 )
-        mc += 360.0;
-    else if ( mc >= 360.0 )
-        mc -= 360.0;
-
-    return mc;
-}
-
-double vhfAC(double st, float lat)
-{   double	oa, ac, m, a;
-
-    oa = st * 15.0 + 90.0;	// secs / (4.0*60.0) + 90.0
-    ac  = Acot( COS_E*Cot(oa) - SIN_E*Tan(lat)/Sin(oa) );
-    if ( ac < 0 )
-        ac += 360.0;
-
-    /* AC is ccw from MC */
-    m = vhfMC(st);
-    ac = ((a = angle(ac, m)) < 180.0) ? ac : ac+180.0;
-    if ( ac >= 360.0 )
-        ac -= 360.0;
-
-    /* from 18:00 - 06:00 sideralTime -> ac = 0 - 180 degree
-     * from 06:00 - 18:00 sideralTime -> ac = 180 - 360 degree
-     * these are the points where all ACs go through, but not the turn around points !!!
-     */
-    /*if ( s>=21600 && s<64800 )
-    {
-        if ( ac<180.0 )
-            ac += 180.0;
-    }
-    else if ( ac>180.0 )
-        ac -= 180.0;*/
-
-    return ac;
-}
-
-/* get latitude for AC or DC degree
- */
-BOOL vhfIsAC(float lat, float acDeg, double st)
-{   float	a = angle(vhfAC(st, lat), acDeg);
-
-    if ( a < 10.0 || a > 350.0)
-        return YES;
-    return NO;
-}
-
-/* MC + UTC -> sideral time
- * FIXME: we don't need UTC for the sideral time offset (without date) we return
- */
-double vhfSideralTimeForMC(float mcDeg, NSCalendarDate *utc)
-{   double	l, mc, ra, st;
-
-    mc = mcDeg;
-    /*if (mcDeg > 180.0)
-        mc -= 180.0;*/
-
-    l = Cot(mc);
-    ra = Acot(l / COS_E);
-    if (mcDeg >= 90.0 && mcDeg < 270.0)
-        ra += 180.0;
-    else if (mcDeg >= 270)
-        ra += 360.0;
-    st = ra * (4.0*60.0) / 3600.0;
-
-    return st;
-}
-
-/* the opposite direction for AC/MC
- * MC + UTC -> longitude
- */
-float vhfLonForMC(float mcDeg, NSCalendarDate *utc)
-{   double	st;
-    float	lon;
-
-    st  = vhfSideralTimeForMC(mcDeg, utc);
-    lon = vhfLonForSideralTime(st, utc);
-    return lon;
-}
-
-/* this returns either AC or DC. check later with isAC()
- */
-float vhfLatForAC(float acDeg, double st)
-{   double	l, oa, lat;
-
-    oa = (st * 3600.0) / (4.0*60.0) + 90.0;
-    /* FIXME: if acDeg == 0.0 -> Cot(acDeg) gets infinity */
-    l = Cot(acDeg);
-    lat = Atan( (COS_E*Cot(oa) - l) * Sin(oa) / SIN_E );
-
-    return lat;
-}
-
-
-
-/*
- * NSCalendarDate functions (slower)
- */
-
 NSCalendarDate *sideralTime(NSCalendarDate *gmt, float longitude)
 {   double	mj, mjd0, t, ut, gmst, lmst;
 
-    mj = vhfMJD(gmt);
+    longitude = -longitude;
+
+    mj = mjd(gmt);
+//NSLog(@"gmt:%@ gmt1:%@", gmt, dateFromMJD(mj));
+
     mjd0 = floor( mj );
     ut = (mj-mjd0)*24;
     t = (mjd0-51544.5)/36525.0;
     gmst = 6.697374558+1.0027379093*ut+(8640184.812866+(0.093104-6.2e-6*t)*t)*t/3600.0;
-    lmst = 24.0*frac((gmst+longitude/15.0)/24.0);
+    lmst = 24.0*frac((gmst-longitude/15.0)/24.0);
 
     gmt = [NSCalendarDate dateWithString: [gmt descriptionWithCalendarFormat:@"%Y%m%d 00:00:00 %z"]
                           calendarFormat:@"%Y%m%d %H:%M:%S %z"];
     return [gmt dateByAddingYears:0 months:0 days:0 hours:0 minutes:0 seconds:(int)(lmst*3600.0)];
 }
-/*float longitudeWithSideralTime(NSCalendarDate *st, NSCalendarDate *gmt)
+float longitudeWithSideralTime(NSCalendarDate *st, NSCalendarDate *gmt)
 {   double	mj, mjd0, t, ut, gmst, lmst, lon;
 
-    mj = vhfMJD(gmt);
+    mj = mjd(gmt);
     mjd0 = floor( mj );
     ut = (mj-mjd0)*24;
     t = (mjd0-51544.5)/36525.0;
@@ -714,15 +459,15 @@ NSCalendarDate *sideralTime(NSCalendarDate *gmt, float longitude)
         lon -= 360.0;
 
     return lon;
-}*/
+}
 
-/*float ra( NSCalendarDate *sideralTime)
+float ra( NSCalendarDate *sideralTime)
 {   float	s, ra;
 
     s = [sideralTime timeIntervalSinceDate:[NSCalendarDate dateWithString:[sideralTime descriptionWithCalendarFormat:@"%Y.%m.%d-00:00 %z"] calendarFormat:@"%Y.%m.%d-%H:%M %z"]];
     ra = s / (4.0*60.0);
     return ra;
-}*/
+}
 
 float mc( NSCalendarDate *sideralTime)
 {   float	s, l, mc, ra;
@@ -752,15 +497,17 @@ float mc( NSCalendarDate *sideralTime)
     else if ( mc >= 360.0 )
         mc -= 360.0;
 
+//NSLog(@"mc(): -> mc=%f   s = 0 >= %f < 43200", mc, s);
+//NSLog(@"in -> st=%@ s=%f, ra=%f, l=%f, mc=%f", [sideralTime descriptionWithCalendarFormat:@"%Y%m%d%H%M%S %Z"], s, ra, l, mc);
     return mc;
 }
-/*static NSCalendarDate *sideralTimeWithMC(float mcDeg, NSCalendarDate *utc)
+NSCalendarDate *sideralTimeWithMC(float mcDeg, NSCalendarDate *utc)
 {   float		s, l, mc, ra;
     NSCalendarDate	*st;
 
     mc = mcDeg;
-    //if (mcDeg > 180.0)
-    //    mc -= 180.0;
+    /*if (mcDeg > 180.0)
+        mc -= 180.0;*/
 
     l = Cot(mc);
     ra = Acot(l / COS_E);
@@ -772,9 +519,10 @@ float mc( NSCalendarDate *sideralTime)
     st = [[NSCalendarDate dateWithString:[utc descriptionWithCalendarFormat:@"%Y%m%d 00:00:00 %z"]
                           calendarFormat:@"%Y%m%d %H:%M:%S %z"]
           dateByAddingYears:0 months:0 days:0 hours:0 minutes:0 seconds:s];
+//NSLog(@"ou -> st=%@ s=%f, ra=%f, l=%f, mc=%f", [st descriptionWithCalendarFormat:@"%Y%m%d%H%M%S %Z"], s, ra, l, mc);
 
     return st;
-}*/
+}
 
 float ac( NSCalendarDate *sideralTime, float lat)
 {   double	s, oa, ac, m, a;
@@ -803,42 +551,43 @@ float ac( NSCalendarDate *sideralTime, float lat)
     else if ( ac>180.0 )
         ac -= 180.0;*/
 
+//NSLog(@"ac(): -> ac=%f  mc=%f a=%f   s = 21600 >= %f < 64800   lat=%f", ac, m, a, s, lat);
     return ac;
 }
 
 /* get latitude for AC or DC degree
  */
-/*BOOL isAC(float lat, float acDeg, NSCalendarDate *sideralTime)
+BOOL isAC(float lat, float acDeg, NSCalendarDate *sideralTime)
 {   float	a = angle(ac(sideralTime, lat), acDeg);
 
     if ( a < 10.0 || a > 350.0)
         return YES;
     return NO;
-}*/
+}
 
 /* the opposite direction for AC/MC
  */
-/*float longitudeForMC(float mcDeg, NSCalendarDate *utc)
+float longitudeForMC(float mcDeg, NSCalendarDate *utc)
 {   NSCalendarDate	*sideralTime;
     float		lon;
 
     sideralTime = sideralTimeWithMC(mcDeg, utc);
     lon = longitudeWithSideralTime(sideralTime, utc);
     return lon;
-}*/
+}
 /* this returns either AC or DC. check later with isAC()
  */
-/*float latitudeForAC(float acDeg, NSCalendarDate *sideralTime)
+float latitudeForAC(float acDeg, NSCalendarDate *sideralTime)
 {   double	s, l, oa, lat;
 
     s = [sideralTime timeIntervalSinceDate:[NSCalendarDate dateWithString:[sideralTime descriptionWithCalendarFormat:@"%Y.%m.%d-00:00-%z"] calendarFormat:@"%Y.%m.%d-%H:%M-%z"]];
     oa = s / (4.0*60.0) + 90.0;
-    // FIXME: if acDeg == 0.0 -> Cot(acDeg) gets infinity
+    /* FIXME: if acDeg == 0.0 -> Cot(acDeg) gets infinity */
     l = Cot(acDeg);
     lat = Atan( (COS_E*Cot(oa) - l) * Sin(oa) / SIN_E );
 
     return lat;
-}*/
+}
 
 /* convert planet string to planet symbol
  */
@@ -877,11 +626,9 @@ NSString *planetSymbol(NSString *planet)
     if ( [planet isEqual:@"Juno"] || [planet isEqual:@"Hera"] )
         return @"Z";
     if ( [planet isEqual:@"Pallas"] || [planet isEqual:@"Minerva"] )
-        return @"[";
+        return @"(";
     if ( [planet isEqual:@"Vesta"] )
         return @"\\";
-    if ( [planet isEqual:@"Pholus"] )
-        return @"o";
     if ( [planet isEqual:@"AC"] )
         return @"P";
     if ( [planet isEqual:@"DC"] )
@@ -958,11 +705,9 @@ NSString *nodeSymbol(NSString *planet)
     if ( [planet isEqual:@"Juno"] || [planet isEqual:@"Hera"] )
         return @"ZT";
     if ( [planet isEqual:@"Pallas"] || [planet isEqual:@"Minerva"] )
-        return @"[T";
+        return @"(T";
     if ( [planet isEqual:@"Vesta"] )
         return @"\\T";
-    if ( [planet isEqual:@"Pholus"] )
-        return @"oT";
     return @"?";
 }
 
@@ -995,11 +740,9 @@ NSString *southNodeSymbol(NSString *planet)
     if ( [planet isEqual:@"Juno"] || [planet isEqual:@"Hera"] )
         return @"ZU";
     if ( [planet isEqual:@"Pallas"] || [planet isEqual:@"Minerva"] )
-        return @"[U";
+        return @"(U";
     if ( [planet isEqual:@"Vesta"] )
         return @"\\U";
-    if ( [planet isEqual:@"Pholus"] )
-        return @"oU";
     return @"?";
 }
 
@@ -1068,13 +811,6 @@ NSString *aspectSymbol(float deg, float orb)
     return nil;
 }
 
-/* remainder = num % denom
- */
-/*double modulo(double num, double denom)
-{
-    return (num - floor(num / denom) * denom);
-}*/
-
 /* bring deg to interval [0, 360]
  */
 double mod360(double deg)
@@ -1087,7 +823,7 @@ double mod360(double deg)
 }
 /* put angle within [0, 359.999]
  */
-double standardAngle( double angle )	// same as angle
+double standardAngle( double angle )
 {
     while ( angle >= 360.0 )
         angle -= 360.0;
@@ -1102,7 +838,7 @@ double angle180( double deg1, double deg2 )
 {   double ang = angle(deg1, deg2);
 
     if ( ang >= 180.0 )
-        ang = 360.0 - ang;
+	ang = 360.0 - ang;
     return ang;
 }
 /* angle = object1 - object2
@@ -1149,32 +885,3 @@ double harmony( double obj, double obj1, double obj2)
         return 180.0 * b / a;
     return -180.0 * (180.0 - b) / (360.0 - a);
 }
-
-
-/* check degFr <= deg <= degTo -> return YES
- * we use a fixed modulus 360
- * and pay attention to overflowing degrees at the 0/360 degree boundary
- * parameter:
- *   degFr  degree at earlier time
- *   deg    degree to test
- *   degTo  degree at later time
- *   retro  NO  = direct     -> degFr < deg < degTo
- *          YES = retrograde -> degTo < deg < degFr
- */
-BOOL vhfIsDegreeInsideRange(double deg, double degFr, double degTo, BOOL retro)
-{
-    if (retro)	// exchange degFr and degTo
-    {   double  v = degFr;
-        degFr = degTo;
-        degTo = v;
-    }
-    if (degFr < 0.0)	// bring degFr above 0 (2006-05-31)
-        degFr += 360.0;
-    if (degTo < degFr)	// bring degTo behind degFr
-        degTo += 360.0;
-    if (deg < degFr)	// bring deg behind degFr
-        deg += 360.0;
-    if ( degFr <= deg && deg <= degTo)
-        return YES;
-    return NO;
-}
